import { useState, useMemo } from 'react'
import { Button, Flex, Modal, Table, Checkbox } from 'antd'
import { DownloadOutlined } from '@ant-design/icons'

export default function ButtonModal() {
  const [open, setOpen] = useState(false)
  const [title, setTitle] = useState('')

  const handleOpen = (button: { name: string; key: string }) => {
    setSelectedButtons([button.key])
    setTitle(`探索` + button.name)
    setOpen(true)
  }

  const buttons = useMemo(() => {
    return [
      { name: '最大值', key: 'max' },
      { name: '最小值', key: 'min' },
      { name: '平均值', key: 'mean' },
      { name: '中位数', key: 'median' },
      { name: '众数', key: 'mode' },
      { name: '1/4位数', key: 'q1' },
      { name: '3/4位数', key: 'q3' },
      { name: '方差', key: 'variance' },
      { name: '标准差', key: 'stdDev' },
      { name: '极差', key: 'range' },
    ]
  }, [])

  const [selectedButtons, setSelectedButtons] = useState<string[]>(['max'])

  const dataSource = [
    {
      key: '1',
      name: '学段1',
      max: 99,
      min: '--',
      mean: 50,
      median: 50,
      mode: 50,
      q1: 25,
      q3: 75,
      variance: 100,
      stdDev: 10,
      range: 99,
    },
    {
      key: '2',
      name: '学段2',
      max: 102586,
      min: '--',
      mean: 51293,
      median: 51293,
      mode: 51293,
      q1: 25646,
      q3: 76939,
      variance: 1000000,
      stdDev: 1000,
      range: 102586,
    },
    {
      key: '3',
      name: '学段3',
      max: 859,
      min: '--',
      mean: 430,
      median: 430,
      mode: 430,
      q1: 215,
      q3: 645,
      variance: 10000,
      stdDev: 100,
      range: 859,
    },
    {
      key: '4',
      name: '学段4',
      max: 1568,
      min: '--',
      mean: 784,
      median: 784,
      mode: 784,
      q1: 392,
      q3: 1176,
      variance: 20000,
      stdDev: 141,
      range: 1568,
    },
  ]

  const columns = useMemo(() => {
    const baseColumns = [
      {
        title: '序号',
        dataIndex: 'key',
        width: 62,
        align: 'center' as const,
      },
      {
        title: '字段名称',
        dataIndex: 'name',
        align: 'center' as const,
      },
    ]

    const selectedColumns = buttons
      .filter((button) => selectedButtons.includes(button.key))
      .map((button) => ({
        title: button.name,
        dataIndex: button.key,
        align: 'center' as const,
      }))

    return [...baseColumns, ...selectedColumns]
  }, [selectedButtons, buttons])

  const handleButtonChange = (checkedValues: string[]) => {
    setSelectedButtons(checkedValues)
  }
  return (
    <>
      {buttons.map((button) => (
        <Button type="primary" key={button.key} onClick={() => handleOpen(button)}>
          {button.name}
        </Button>
      ))}
      <Modal
        title={title}
        open={open}
        footer={
          <Flex justify="center" gap={20}>
            <Button type="primary">一键计算</Button>
          </Flex>
        }
        destroyOnClose
        width={1000}
        onCancel={() => setOpen(false)}>
        <div style={{ minHeight: 300, padding: '20px 0' }}>
          <Flex justify="space-between" align="center" style={{ marginBottom: '20px' }}>
            <div>
              请选择字段：
              <Button type="text" icon={<DownloadOutlined />} size="small">
                导出
              </Button>
            </div>
            <Checkbox.Group value={selectedButtons} onChange={handleButtonChange}>
              {buttons.map((button) => (
                <Checkbox key={button.key} value={button.key}>
                  {button.name}
                </Checkbox>
              ))}
            </Checkbox.Group>
          </Flex>
          <Table bordered dataSource={dataSource} columns={columns} pagination={false} scroll={{ x: 'max-content' }} />
        </div>
      </Modal>
    </>
  )
}
